@@ -10,15 +10,12 @@ import boto3
 import glob
 import os
 import shutil
-import docker
 import pkg_resources
 import subprocess
 from sagemaker.multidatamodel import MultiDataModel
 from sagemaker.model import Model
 import ast
 import csv
-import multiprocessing
-from functools import partial
 import json
 import pickle
 
